@@ -6,7 +6,7 @@ use warnings;
 use Text::Markup::None;
 use Carp;
 
-our $VERSION = '0.25';
+our $VERSION = '0.30';
 
 my %_PARSER_FOR;
 my %REGEX_FOR = (
@@ -123,7 +123,7 @@ This distribution includes support for a number of markup formats:
 
 =over
 
-=item * L<Asciidoc|https://asciidoc-py.github.io/>
+=item * L<Asciidoc|https://asciidoc.org>
 
 =item * L<BBcode|https://www.bbcode.org/>
 
@@ -333,8 +333,8 @@ In such a case, read in the file as raw bytes:
 
 The returned HTML, however, B<must be encoded in UTF-8>. Please include an
 L<encoding
-declaration|https://en.wikipedia.org/wiki/Character_encodings_in_HTML>, such as
-a content-type C<< <meta> >> element:
+declaration|https://en.wikipedia.org/wiki/Character_encodings_in_HTML>, such
+as a content-type C<< <meta> >> element:
 
   <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
 
